@@ -269,6 +269,12 @@ def add_infrastructure_options(o):
       "-Z", "--quick", action="store_true",
       dest="quick", default=None,
       help=("Only do an approximation."))
+  o.add_argument(
+      "--check-nonnull-parameter-types", action="store_true",
+      dest="check_nonnull_parameter_types", default=False,
+      help=("Temporary flag to aid in the rollout of --check-parameter-types. "
+            "Do not use! Use --check-parameter-types instead, which enables a "
+            "superset of the checks enabled by this flag."))
 
 
 def add_debug_options(o):
@@ -538,8 +544,7 @@ class Postprocessor:
 
       with verbosity_from(self.output_options):
         self.output_options.imports_map = imports_map_loader.build_imports_map(
-            imports_map, self.output_options.output,
-            self.output_options.open_function)
+            imports_map, self.output_options.open_function)
     else:
       self.output_options.imports_map = None
 
