@@ -66,9 +66,8 @@ class Converter(utils.VirtualMachineWeakrefMixin):
 
     # Now fill primitive_classes with the real values using constant_to_value.
     primitive_classes = [
-        int, float, str, object, frozenset, compat.NoneType, complex, bool,
-        slice, types.CodeType, compat.EllipsisType, compat.OldStyleClassType,
-        super
+        int, float, str, object, compat.NoneType, complex, bool, slice,
+        types.CodeType, compat.EllipsisType, compat.OldStyleClassType, super,
     ] + version_specific
     self.primitive_classes = {
         v: self.constant_to_value(v) for v in primitive_classes
@@ -169,9 +168,8 @@ class Converter(utils.VirtualMachineWeakrefMixin):
       return "builtins." + t.__name__
 
   def value_to_constant(self, val, constant_type):
-    if (isinstance(val, mixin.PythonConstant) and
-        isinstance(val.pyval, constant_type or object) and
-        not getattr(val, "could_contain_anything", False)):
+    if (abstract_utils.is_concrete(val) and
+        isinstance(val.pyval, constant_type or object)):
       return val.pyval
     name = self.constant_name(constant_type)
     raise abstract_utils.ConversionError("%s is not of type %s" % (val, name))
@@ -496,9 +494,7 @@ class Converter(utils.VirtualMachineWeakrefMixin):
         try:
           cls = ast.Lookup(late_type.name)
         except KeyError:
-          try:
-            ast.Lookup("__getattr__")
-          except KeyError:
+          if "__getattr__" not in ast:
             log.warning("Couldn't resolve %s", late_type.name)
           t = pytd.AnythingType()
         else:
@@ -569,6 +565,13 @@ class Converter(utils.VirtualMachineWeakrefMixin):
       return self.primitive_class_instances[int]
     elif pyval.__class__ in self.primitive_classes:
       return self.primitive_class_instances[pyval.__class__]
+    elif pyval.__class__ is frozenset:
+      instance = abstract.Instance(self.frozenset_type, self.vm)
+      for element in pyval:
+        instance.merge_instance_type_parameter(
+            self.vm.root_node, abstract_utils.T, self.constant_to_var(
+                element, subst, self.vm.root_node))
+      return instance
     elif isinstance(pyval, (loadmarshal.CodeType, blocks.OrderedCode)):
       return abstract.ConcreteValue(pyval,
                                     self.primitive_classes[types.CodeType],
@@ -704,7 +707,10 @@ class Converter(utils.VirtualMachineWeakrefMixin):
           if isinstance(c, pytd.TypeParameter):
             if not subst or c.full_name not in subst:
               raise self.TypeParameterError(c.full_name)
-            return self.merge_classes(subst[c.full_name].data)
+            # deformalize gets rid of any unexpected TypeVars, which can appear
+            # if something is annotated as Type[T].
+            return self.vm.annotations_util.deformalize(
+                self.merge_classes(subst[c.full_name].data))
           else:
             return self.constant_to_value(c, subst, self.vm.root_node)
         elif isinstance(cls, pytd.TupleType):
