@@ -9,10 +9,10 @@ import sys
 from typing import Iterable, Optional, Union
 
 from pytype import abstract
+from pytype import abstract_utils
 from pytype import class_mixin
 from pytype import debug
 from pytype import function
-from pytype import mixin
 from pytype import utils
 from pytype.pytd import escape
 from pytype.pytd import optimize
@@ -499,8 +499,7 @@ class ErrorLog(ErrorLogBase):
       with t.vm.convert.pytd_convert.set_output_mode(
           t.vm.convert.pytd_convert.OutputMode.DETAILED):
         return self._pytd_print(t.get_instance_type(instance=instance))
-    elif (isinstance(t, mixin.PythonConstant) and
-          not getattr(t, "could_contain_anything", False)):
+    elif abstract_utils.is_concrete(t):
       return re.sub(r"(\\n|\s)+", " ",
                     t.str_of_constant(self._print_as_expected_type))
     elif isinstance(t, abstract.AnnotationClass) or not t.cls:
@@ -1034,9 +1033,10 @@ class ErrorLog(ErrorLogBase):
 
   @_error_name("reveal-type")
   def reveal_type(self, stack, node, var):
-    types = [self._print_as_actual_type(b.data)
-             for b in var.bindings
-             if node.HasCombination([b])]
+    types = [
+        self._print_as_actual_type(b.data)
+        for b in abstract_utils.expand_type_parameter_instances(var.bindings)
+        if node.HasCombination([b])]
     self.error(stack, self._join_printed_types(types))
 
   @_error_name("annotation-type-mismatch")
