@@ -53,6 +53,7 @@ class Converter(utils.VirtualMachineWeakrefMixin):
   def __init__(self, vm):
     super().__init__(vm)
     self._output_mode = Converter.OutputMode.NORMAL
+    self._scopes = []
 
   @contextlib.contextmanager
   def set_output_mode(self, mode):
@@ -235,7 +236,9 @@ class Converter(utils.VirtualMachineWeakrefMixin):
     if isinstance(v, (abstract.Empty, typing_overlay.NoReturn)):
       return pytd.NothingType()
     elif isinstance(v, abstract.TypeParameterInstance):
-      if v.instance.get_instance_type_parameter(v.full_name).bindings:
+      if v.module in self._scopes:
+        return self._typeparam_to_def(node, v.param, v.param.name)
+      elif v.instance.get_instance_type_parameter(v.full_name).bindings:
         # The type parameter was initialized. Set the view to None, since we
         # don't include v.instance in the view.
         return pytd_utils.JoinTypes(
@@ -384,7 +387,7 @@ class Converter(utils.VirtualMachineWeakrefMixin):
           name=name,
           signatures=tuple(sig.pytd_sig for sig in v.signatures),
           kind=v.kind,
-          flags=pytd.Function.abstract_flag(v.is_abstract))
+          flags=pytd.MethodFlags.abstract_flag(v.is_abstract))
     elif isinstance(v, abstract.InterpreterFunction):
       return self._function_to_def(node, v, name)
     elif isinstance(v, abstract.SimpleFunction):
@@ -492,8 +495,8 @@ class Converter(utils.VirtualMachineWeakrefMixin):
           for combination in combinations)
     return pytd.Function(name=function_name,
                          signatures=tuple(signatures),
-                         kind=pytd.METHOD,
-                         flags=pytd.Function.abstract_flag(v.is_abstract))
+                         kind=pytd.MethodTypes.METHOD,
+                         flags=pytd.MethodFlags.abstract_flag(v.is_abstract))
 
   def _simple_func_to_def(self, node, v, name):
     """Convert a SimpleFunction to a PyTD definition."""
@@ -528,7 +531,7 @@ class Converter(utils.VirtualMachineWeakrefMixin):
         return_type=ret_type,
         exceptions=(),
         template=())
-    return pytd.Function(name, (pytd_sig,), pytd.METHOD)
+    return pytd.Function(name, (pytd_sig,), pytd.MethodTypes.METHOD)
 
   def _function_to_return_types(self, node, fvar):
     """Convert a function variable to a list of PyTD return types."""
@@ -573,6 +576,7 @@ class Converter(utils.VirtualMachineWeakrefMixin):
 
   def _class_to_def(self, node, v, class_name):
     """Convert an InterpreterClass to a PyTD definition."""
+    self._scopes.append(class_name)
     methods = {}
     constants = collections.defaultdict(pytd_utils.TypeBuilder)
 
@@ -599,13 +603,13 @@ class Converter(utils.VirtualMachineWeakrefMixin):
         elif isinstance(value, special_builtins.StaticMethodInstance):
           try:
             methods[name] = self._static_method_to_def(
-                node, value, name, pytd.STATICMETHOD)
+                node, value, name, pytd.MethodTypes.STATICMETHOD)
           except abstract_utils.ConversionError:
             constants[name].add_type(pytd.AnythingType())
         elif isinstance(value, special_builtins.ClassMethodInstance):
           try:
             methods[name] = self._class_method_to_def(
-                node, value, name, pytd.CLASSMETHOD)
+                node, value, name, pytd.MethodTypes.CLASSMETHOD)
           except abstract_utils.ConversionError:
             constants[name].add_type(pytd.AnythingType())
         elif isinstance(value, abstract.Function):
@@ -628,13 +632,33 @@ class Converter(utils.VirtualMachineWeakrefMixin):
           else:
             constants[name].add_type(value.to_type(node))
 
-    # instance-level attributes
-    for instance in set(v.instances):
+    # Instance-level attributes: all attributes from 'canonical' instances (that
+    # is, ones created by analyze.py:analyze_class()) are added. Attributes from
+    # non-canonical instances are added if their canonical values do not contain
+    # type parameters.
+    ignore = set(annotated_names)
+    canonical_attributes = set()
+
+    def add_attributes_from(instance):
       for name, member in instance.members.items():
-        if name in CLASS_LEVEL_IGNORE or name in annotated_names:
+        if name in CLASS_LEVEL_IGNORE or name in ignore:
           continue
         for value in member.FilteredData(self.vm.exitpoint, strict=False):
-          constants[name].add_type(value.to_type(node))
+          typ = value.to_type(node)
+          collector = visitors.CollectTypeParameters()
+          typ.Visit(collector)
+          if collector.params:
+            # This attribute's type comes from an annotation that contains a
+            # type parameter; we do not want to merge in substituted values of
+            # the type parameter.
+            canonical_attributes.add(name)
+          constants[name].add_type(typ)
+
+    for instance in v.canonical_instances:
+      add_attributes_from(instance)
+    ignore |= canonical_attributes
+    for instance in v.instances - v.canonical_instances:
+      add_attributes_from(instance)
 
     for name in list(methods):
       if name in constants:
@@ -687,6 +711,7 @@ class Converter(utils.VirtualMachineWeakrefMixin):
     for base in missing_bases:
       base_cls = self.value_to_pytd_def(node, base, base.name)
       cls = pytd_utils.MergeBaseClass(cls, base_cls)
+    self._scopes.pop()
     return cls
 
   def _typeparam_to_def(self, node, v, name):
